package com.cirs.biz.service.impl;

import java.util.List;
import com.cirs.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.cirs.biz.mapper.TPageViewTimeMapper;
import com.cirs.biz.domain.TPageViewTime;
import com.cirs.biz.service.ITPageViewTimeService;

/**
 * 页面浏览时长Service业务层处理
 * 
 * @author allen
 * @date 2023-11-03
 */
@Service
public class TPageViewTimeServiceImpl implements ITPageViewTimeService 
{
    @Autowired
    private TPageViewTimeMapper tPageViewTimeMapper;

    /**
     * 查询页面浏览时长
     * 
     * @param id 页面浏览时长主键
     * @return 页面浏览时长
     */
    @Override
    public TPageViewTime selectTPageViewTimeById(Long id)
    {
        return tPageViewTimeMapper.selectTPageViewTimeById(id);
    }

    /**
     * 查询页面浏览时长列表
     * 
     * @param tPageViewTime 页面浏览时长
     * @return 页面浏览时长
     */
    @Override
    public List<TPageViewTime> selectTPageViewTimeList(TPageViewTime tPageViewTime)
    {
        return tPageViewTimeMapper.selectTPageViewTimeList(tPageViewTime);
    }

    /**
     * 新增页面浏览时长
     * 
     * @param tPageViewTime 页面浏览时长
     * @return 结果
     */
    @Override
    public int insertTPageViewTime(TPageViewTime tPageViewTime)
    {
        tPageViewTime.setCreateTime(DateUtils.getNowDate());
        return tPageViewTimeMapper.insertTPageViewTime(tPageViewTime);
    }

    /**
     * 修改页面浏览时长
     * 
     * @param tPageViewTime 页面浏览时长
     * @return 结果
     */
    @Override
    public int updateTPageViewTime(TPageViewTime tPageViewTime)
    {
        tPageViewTime.setUpdateTime(DateUtils.getNowDate());
        return tPageViewTimeMapper.updateTPageViewTime(tPageViewTime);
    }

    /**
     * 批量删除页面浏览时长
     * 
     * @param ids 需要删除的页面浏览时长主键
     * @return 结果
     */
    @Override
    public int deleteTPageViewTimeByIds(Long[] ids)
    {
        return tPageViewTimeMapper.deleteTPageViewTimeByIds(ids);
    }

    /**
     * 删除页面浏览时长信息
     * 
     * @param id 页面浏览时长主键
     * @return 结果
     */
    @Override
    public int deleteTPageViewTimeById(Long id)
    {
        return tPageViewTimeMapper.deleteTPageViewTimeById(id);
    }
}
